@@ -16,7 +16,6 @@ from .translation_utils import get_language_pack, get_language_packs, is_valid_l
 
 
 class TranslationsHandler(SchemaHandler):
-
     @gen.coroutine
     @tornado.web.authenticated
     def get(self, locale=""):
@@ -29,19 +28,18 @@ class TranslationsHandler(SchemaHandler):
             If no locale is provided, it will list all the installed language packs.
             Default is `""`.
         """
+        data: dict
         data, message = {}, ""
         try:
             if locale == "":
-                data, message = get_language_packs(
-                    display_locale=self.get_current_locale()
-                )
+                data, message = get_language_packs(display_locale=self.get_current_locale())
             else:
                 data, message = get_language_pack(locale)
                 if data == {} and message == "":
                     if is_valid_locale(locale):
-                        message = "Language pack '{}' not installed!".format(locale)
+                        message = f"Language pack '{locale}' not installed!"
                     else:
-                        message = "Language pack '{}' not valid!".format(locale)
+                        message = f"Language pack '{locale}' not valid!"
                 else:
                     # only change locale if the language pack is installed and valid
                     if is_valid_locale(locale):
